pystagram.graph_api.components.strtotime package — pystagram 0.1 documentation

# pystagram.graph_api.components.strtotime package

## Submodules

## pystagram.graph_api.components.strtotime.strtotime module

class pystagram.graph_api.components.strtotime.strtotime.Strtotime

  Bases: `str`

  A class to represent a strtotime. Inherits from str. Strtotime is a string that represents a date and time in a human-readable format. See https://www.php.net/manual/en/function.strtotime.php for more information.

## Module contents